import socket
import time
import sys
import os

# Default maps directory - change this if your maps are in a different location
MAPS_DIR = r"C:\Users\rust9\AppData\Roaming\DDNet\maps"

def send_econ_command(command, password="test123", host="127.0.0.1", port=8303):
    """Send a command through econ with configurable settings"""
    try:
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        sock.settimeout(5)
        
        print(f"Connecting to econ on {host}:{port}...")
        sock.connect((host, port))
        print("Connected!")
        
        # Wait for initial prompt
        sock.recv(1024)
        
        # Send authentication
        print("Authenticating...")
        sock.send(password.encode() + b"\n")
        time.sleep(0.5)  # Wait for auth
        
        # Clear auth response
        sock.recv(1024)
        
        # Send the command
        print(f"Sending command: {command}")
        sock.send(command.encode() + b"\n")
        time.sleep(0.5)  # Wait for command to process
        
        return True
    except Exception as e:
        print(f"Error: {str(e)}")
        return False
    finally:
        sock.close()

def list_available_maps():
    """List all available maps in the maps directory"""
    maps = [f for f in os.listdir(MAPS_DIR) if f.endswith('.map')]
    return maps

def change_map(map_name):
    """Change to specified map using econ"""
    # Check if map exists (case insensitive)
    available_maps = list_available_maps()
    map_exists = any(m.lower() == map_name.lower() for m in available_maps)
    
    if not map_exists:
        # Try to find the map with .map extension
        map_with_ext = map_name + '.map'
        map_exists = any(m.lower() == map_with_ext.lower() for m in available_maps)
        if map_exists:
            map_name = map_name  # Don't include .map extension in command
        else:
            print(f"Warning: Map '{map_name}' not found in {MAPS_DIR}")
            print("\nAvailable maps:")
            for m in sorted(available_maps):
                print(f"- {m[:-4]}")  # Remove .map extension
            return False
    
    command = f"change_map {map_name}"
    return send_econ_command(command)

if __name__ == "__main__":
    # Get map name from command line argument
    if len(sys.argv) != 2:
        print("Usage: python change_map_econ.py <map_name>")
        print("Example: python change_map_econ.py Rain")
        print("\nAvailable maps:")
        for m in sorted(list_available_maps()):
            print(f"- {m[:-4]}")  # Remove .map extension
        sys.exit(1)
    
    map_name = sys.argv[1]
    print(f"Attempting to change map to: {map_name}")
    change_map(map_name)
